==> cvxpy-0.1.tar.gz: cvxpy-0.1/cvxpy/atoms/__init__.py <==
"""
Copyright 2013 Steven Diamond

This file is part of CVXPY.

CVXPY is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CVXPY is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
"""

from geo_mean import geo_mean
from kl_div import kl_div
from lambda_max import lambda_max
from lambda_min import lambda_min
from log_det import log_det
from log_sum_exp import log_sum_exp
from norm import norm
from norm1 import norm1
from norm2 import norm2
from norm_inf import normInf
from norm_nuc import normNuc
from quad_form import quad_form
from quad_over_lin import quad_over_lin
from sigma_max import sigma_max

from affine.sum import sum
from affine.vstack import vstack

from elementwise.abs import abs
from elementwise.entr import entr
from elementwise.exp import exp
from elementwise.inv_pos import inv_pos
from elementwise.log import log
from elementwise.max import max
from elementwise.min import min
from elementwise.neg import neg
from elementwise.pos import pos
from elementwise.sqrt import sqrt
from elementwise.square import square

==> cvxpy-0.2.tar.gz: cvxpy-0.2/cvxpy/atoms/__init__.py <==
"""
Copyright 2013 Steven Diamond

This file is part of CVXPY.

CVXPY is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

CVXPY is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
"""

from geo_mean import geo_mean
from kl_div import kl_div
from lambda_max import lambda_max
from lambda_min import lambda_min
from log_det import log_det
from log_sum_exp import log_sum_exp
from norm import norm
from norm1 import norm1
from norm2 import norm2
from norm_inf import normInf
from norm_nuc import normNuc
from quad_form import quad_form
from quad_over_lin import quad_over_lin
from sigma_max import sigma_max
from sum_squares import sum_squares

from affine.conv import conv
from affine.hstack import hstack
from affine.sum_entries import sum_entries
from affine.vstack import vstack

from elementwise.abs import abs
from elementwise.entr import entr
from elementwise.exp import exp
from elementwise.huber import huber
from elementwise.inv_pos import inv_pos
from elementwise.log import log
from elementwise.max_elemwise import max_elemwise
from elementwise.min_elemwise import min_elemwise
from elementwise.neg import neg
from elementwise.pos import pos
from elementwise.sqrt import sqrt
from elementwise.square import square
